pub struct SeqData<D = Vec<u8>> { /* private fields */ }Expand description
Sequence-numbered non-marked data.
It is a subset of SeqMarked where data is always normal.
use seq_marked::SeqData;
let v1 = SeqData::new(1, "data");Implementations
Sourceimpl<D> SeqData<D>
impl<D> SeqData<D>
Sourcepub fn map<U>(self, f: impl FnOnce(D) -> U) -> SeqData<U>
pub fn map<U>(self, f: impl FnOnce(D) -> U) -> SeqData<U>
Transforms data D to U while preserving sequence and tombstone state.
Example
use seq_marked::SeqData;
let a = SeqData::new(1, "data");
let b = a.map(|x| x.len());
assert_eq!(b.data(), &4);pub fn try_map<U, E>( self, f: impl FnOnce(D) -> Result<U, E>, ) -> Result<SeqData<U>, E>
Sourcepub fn order_key(&self) -> SeqMarked<()>
pub fn order_key(&self) -> SeqMarked<()>
Returns ordering key (sequence + tombstone state only).
Sourcepub fn internal_seq(&self) -> InternalSeq
pub fn internal_seq(&self) -> InternalSeq
Returns the sequence number for internal use, tombstone also has a seq.
Sourcepub fn user_seq(&self) -> u64
pub fn user_seq(&self) -> u64
Returns the sequence number for application use, tombstone always has seq 0.
pub fn into_parts(self) -> (u64, D)
Sourcepub fn display_with_debug(&self) -> impl Display + '_where
D: Debug,
pub fn display_with_debug(&self) -> impl Display + '_where
D: Debug,
Returns formatter for display using Debug trait.