pub struct SeqV<M, T = Vec<u8>> {
pub seq: u64,
pub meta: Option<M>,
pub data: T,
}Expand description
Some value bound with a seq number.
SeqV is the meta-service API level generic value.
Meta-service application uses this type to interact with meta-service.
Inside the meta-service, the value is stored in the form of Marked, which could be a
tombstone. A Marked::TombStone is converted to None::<SeqV> and a Marked::Normal is
converted to Some::<SeqV>.
A Marked::TombStone also has an internal_seq, representing the freshness of the tombstone.
internal_seq will be discarded when Marked::TombStone is converted to None::<SeqV>.
Fields
seq: u64meta: Option<M>data: TImplementations
Sourceimpl<M, T> SeqV<M, T>
impl<M, T> SeqV<M, T>
pub fn new(seq: u64, data: T) -> Self
pub fn new_with_meta(seq: u64, meta: Option<M>, data: T) -> Self
pub fn with_seq(self, seq: u64) -> Self
pub fn with_meta(self, m: Option<M>) -> Self
pub fn with_value(self, v: T) -> Self