SeqMarked

Struct SeqMarked 

pub struct SeqMarked<D = Vec<u8>> { /* private fields */ }
Sequence-numbered marked value.

Ordered by sequence number first, then tombstone > normal.

use seq_marked::SeqMarked;

let v1 = SeqMarked::new_normal(1, "data");
let v2 = SeqMarked::<&str>::new_tombstone(2);
assert!(v1 < v2);

Implementations

Source

impl SeqMarked<()>

pub const fn zero() -> Self

Creates the smallest order key (seq=0, normal).

pub const fn max_value() -> Self

Source

impl<D> SeqMarked<&D>

pub fn cloned(self) -> SeqMarked<D>
where D: Clone,

Source

impl<D> SeqMarked<D>

pub fn new(seq: u64, marked: Marked<D>) -> Self

Creates a new SeqMarked with sequence number and marked data.

pub fn new_normal(seq: u64, data: D) -> Self

Creates normal value with sequence number.

pub fn new_tombstone(seq: u64) -> Self

Creates tombstone with sequence number.

pub fn new_not_found() -> Self

Represents an absent record (not even marked as deleted).

pub fn to_tombstone(self) -> Self

pub fn is_normal(&self) -> bool

Returns true if this is normal data.

pub fn is_tombstone(&self) -> bool

Returns true if this is a tombstone.

pub fn is_not_found(&self) -> bool

pub fn is_absent(&self) -> bool

pub fn map<U>(self, f: impl FnOnce(D) -> U) -> SeqMarked<U>

Transforms data D to U while preserving sequence and tombstone state.

Example
use seq_marked::SeqMarked;

let a = SeqMarked::new_normal(1, "data");
let b = a.map(|x| x.len());
assert_eq!(b.data_ref(), Some(&4));
pub fn try_map<U, E>( self, f: impl FnOnce(D) -> Result<U, E>, ) -> Result<SeqMarked<U>, E>

pub fn as_ref(&self) -> SeqMarked<&D>

Creates reference to the data.

pub fn order_key(&self) -> SeqMarked<()>

Returns ordering key (sequence + tombstone state only).

pub fn internal_seq(&self) -> InternalSeq

Returns the sequence number for internal use, tombstone also has a seq.

pub fn user_seq(&self) -> u64

Returns the sequence number for application use, tombstone always has seq 0.

pub fn max(a: Self, b: Self) -> Self

Returns the maximum of two values.

pub fn max_ref<'l>(a: &'l Self, b: &'l Self) -> &'l Self

Returns the maximum of two values.

pub fn data_ref(&self) -> Option<&D>

Returns reference to data if normal, None if tombstone.

pub fn into_data(self) -> Option<D>

Consumes and returns data if normal, None if tombstone.

pub fn into_parts(self) -> (u64, Marked<D>)

pub fn display_with_debug(&self) -> impl Display + '_
where D: Debug,

Returns formatter for display using Debug trait.