Struct SeqV

pub struct SeqV<M, T = Vec<u8>> {
    pub seq: u64,
    pub meta: Option<M>,
    pub data: T,
}
Some value bound with a seq number.

SeqV is the meta-service API level generic value. Meta-service application uses this type to interact with meta-service.

Inside the meta-service, the value is stored in the form of Marked, which could be a tombstone. A Marked::TombStone is converted to None::<SeqV> and a Marked::Normal is converted to Some::<SeqV>.

A Marked::TombStone also has an internal_seq, representing the freshness of the tombstone. internal_seq will be discarded when Marked::TombStone is converted to None::<SeqV>.

Fields

seq: u64meta: Option<M>data: T

Implementations

Source

impl<M, T> SeqV<M, T>

pub fn new(seq: u64, data: T) -> Self

pub fn new_with_meta(seq: u64, meta: Option<M>, data: T) -> Self

pub fn with_seq(self, seq: u64) -> Self

pub fn with_meta(self, m: Option<M>) -> Self

pub fn with_value(self, v: T) -> Self

pub fn map<U>(self, f: impl FnOnce(T) -> U) -> SeqV<M, U>

Convert data to type U and leave seq and meta unchanged.

pub fn try_map<U, E>( self, f: impl FnOnce(T) -> Result<U, E>, ) -> Result<SeqV<M, U>, E>

Try to convert data to type U and leave seq and meta unchanged. f returns an error if the conversion fails.